@@ -174,8 +174,7 @@ class OpenADRClient:
                    reading_type=enums.READING_TYPE.DIRECT_READ,
                    report_type=enums.REPORT_TYPE.READING, sampling_rate=None, data_source=None,
                    scale="none", unit=None, power_ac=True, power_hertz=50, power_voltage=230,
-                   market_context=None, end_device_asset_mrid=None, report_data_source=None,
-                   on_change=False):
+                   market_context=None, end_device_asset_mrid=None, report_data_source=None):
         """
         Add a new reporting capability to the client.
 
@@ -213,10 +212,6 @@ class OpenADRClient:
         :param str market_context: The Market Context that this report belongs to.
         :param str end_device_asset_mrid: the Meter ID for the end device that is measured by this report.
         :param report_data_source: A (list of) target(s) that this report is related to.
-        :param boolean on_change: Whether this measurement supports reporting when the value changes.
-                                  To use this functionality, call the ``client.report_on_change`` method
-                                  with parameters ``report_id, r_id, value``. You get the ``report_id``
-                                  and the ``r_id`` from the return of the ``client.add_report`` call.
         """
 
         # Verify input
@@ -239,11 +234,11 @@ class OpenADRClient:
         if sampling_rate is None:
             sampling_rate = objects.SamplingRate(min_period=timedelta(seconds=10),
                                                  max_period=timedelta(hours=24),
-                                                 on_change=on_change)
+                                                 on_change=False)
         elif isinstance(sampling_rate, timedelta):
             sampling_rate = objects.SamplingRate(min_period=sampling_rate,
                                                  max_period=sampling_rate,
-                                                 on_change=on_change)
+                                                 on_change=False)
 
         if data_collection_mode not in ('incremental', 'full'):
             raise ValueError("The data_collection_mode should be 'incremental' or 'full'.")
@@ -412,8 +407,7 @@ class OpenADRClient:
 
     async def request_event(self, reply_limit=None):
         """
-        Requests all pending and active events from the VTN, if any.
-        Returns a response_type, response_payload tuple.
+        Request the next Event from the VTN, if it has any.
         """
         payload = {'request_id': utils.generate_id(),
                    'ven_id': self.ven_id,
@@ -553,11 +547,6 @@ class OpenADRClient:
         Create a single report in response to a request from the VTN.
         """
 
-    def update_report_on_change(self, report_id, r_id, value):
-        """
-        Creates a new report after a value changed.
-        """
-
     async def update_report(self, report_request_id):
         """
         Call the previously registered report callback and send the result as a message to the VTN.
@@ -680,7 +669,7 @@ class OpenADRClient:
                        "You should implement your own on_update_event handler. This handler receives "
                        "an Event dict and should return either 'optIn' or 'optOut' based on your "
                        "choice. Will re-use the previous opt status for this event_id for now")
-        if event['event_descriptor']['event_id'] in self.events:
+        if event['event_descriptor']['event_id'] in self.responded_events:
             return self.responded_events['event_id']
 
     async def on_register_report(self, report):
@@ -801,7 +790,7 @@ class OpenADRClient:
                             'response_description': 'OK',
                             'opt_type': results[i],
                             'request_id': message['request_id'],
-                            'modification_number': modification_number,
+                            'modification_number': events[i]['event_descriptor']['modification_number'],
                             'event_id': events[i]['event_descriptor']['event_id']}
                            for i, event in enumerate(events)
                            if event['response_required'] == 'always'
