@@ -163,9 +163,6 @@ class OpenADRServer:
     async def run_async(self):
         await self.run()
 
-    async def run_heroku(self):
-        return self.app
-
     async def stop(self):
         """
         Stop the server in a graceful manner.
